==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/62/62332ad9c0dd5718297f03dc936072e0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Helper/CampaignEventHelper.php */
class __TwigTemplate_f3e40f3053fc5ffb381dc9843e5d170f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CampaignBundle\\Helper;

use Mautic\\CampaignBundle\\Event\\CampaignLeadChangeEvent;

class CampaignEventHelper
{
    /**
     * Determine if this campaign applies.
     */
    public static function validateLeadChangeTrigger(CampaignLeadChangeEvent \$eventDetails = null, array \$event): bool
    {
        if (null == \$eventDetails) {
            return true;
        }

        \$limitToCampaigns = \$event['properties']['campaigns'];
        \$action           = \$event['properties']['action'];

        // check against selected campaigns
        if (!empty(\$limitToCampaigns) && !in_array(\$event['campaign']['id'], \$limitToCampaigns)) {
            return false;
        }

        // check against the selected action (was lead removed or added)
        \$func = 'was'.ucfirst(\$action);
        if (!method_exists(\$eventDetails, \$func) || !\$eventDetails->\$func()) {
            return false;
        }

        return true;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Helper/CampaignEventHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Helper/CampaignEventHelper.php", "/var/www/mautic-ktn/app/bundles/CampaignBundle/Helper/CampaignEventHelper.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/62/62332ad9c0dd5718297f03dc936072e0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Helper/CampaignEventHelper.php */
class __TwigTemplate_f3e40f3053fc5ffb381dc9843e5d170f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CampaignBundle\\Helper;

use Mautic\\CampaignBundle\\Event\\CampaignLeadChangeEvent;

class CampaignEventHelper
{
    /**
     * Determine if this campaign applies.
     */
    public static function validateLeadChangeTrigger(CampaignLeadChangeEvent \$eventDetails = null, array \$event): bool
    {
        if (null == \$eventDetails) {
            return true;
        }

        \$limitToCampaigns = \$event['properties']['campaigns'];
        \$action           = \$event['properties']['action'];

        // check against selected campaigns
        if (!empty(\$limitToCampaigns) && !in_array(\$event['campaign']['id'], \$limitToCampaigns)) {
            return false;
        }

        // check against the selected action (was lead removed or added)
        \$func = 'was'.ucfirst(\$action);
        if (!method_exists(\$eventDetails, \$func) || !\$eventDetails->\$func()) {
            return false;
        }

        return true;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Helper/CampaignEventHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Helper/CampaignEventHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Helper/CampaignEventHelper.php");
    }
}
